import 'dart:async';

import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';

class ExampleController extends GetxController {
  // mark:RabbitDataInstance
  final RabbitDataInstance rabbitData = Get.find(tag: 'rabbit_data');
  late StreamSubscription<String> apiSub;
  late StreamSubscription<String> dbSub;
  late StreamSubscription<int> sizeDBSub;
  late StreamSubscription<Map<String, num>> conditionSub;

  var cpu = 0.obs;
  var memory = 0.obs;
  var battery = 0.obs;
  var freeSpace = 0.obs;
  var sizeDB = 0.obs;

  ExampleController() {
    dbSub = rabbitData.changeDB.listen((value) async {
      //print('Example eventController : $value');
      await getEvents();
    });

    sizeDBSub = rabbitData.sizeDB.listen((value) {
      sizeDB.value = value;
    });

    conditionSub = rabbitData.condition.listen((value) async {
      //print('condition : $value');
      cpu.value = (value['cpu'] ?? 0).toInt();
      memory.value = (value['memory'] ?? 0).toInt();
      battery.value = (value['battery'] ?? 0).toInt();
      freeSpace.value = (value['freeSpace'] ?? 0.0).toInt();
    });

    apiSub = rabbitData.apiResult.listen((value) async {
      if (value.isEmpty || Get.context == null) return;

      print('api result: $value');
      if (value.contains('error')) {
        Get.snackbar('Condition Invalid!', value,
            colorText: Colors.white,
            backgroundColor: Colors.red.shade300,
            snackPosition: SnackPosition.TOP,
            margin: EdgeInsets.symmetric(vertical: 10, horizontal: 10));
      } else if (value == 'storage = min') {
        Get.snackbar('Free storage < Min MB!',
            'Never save to local database. It\'s sending to api now.',
            colorText: Colors.white,
            backgroundColor: Colors.red.shade300,
            snackPosition: SnackPosition.TOP,
            margin: EdgeInsets.symmetric(vertical: 10, horizontal: 10));
      } else if (value == 'storage = deleteOld') {
        Get.snackbar('Free storage between min and max !',
            'Older data was delete then save new data to local database.',
            colorText: Colors.white,
            backgroundColor: Colors.yellow,
            snackPosition: SnackPosition.TOP,
            margin: EdgeInsets.symmetric(vertical: 10, horizontal: 10));
      } else if (value == 'uploadEvent success') {
        Get.snackbar('UploadEvent success', 'Event logs sent to api.',
            colorText: Colors.white,
            backgroundColor: Colors.lightGreen,
            snackPosition: SnackPosition.TOP,
            margin: EdgeInsets.symmetric(vertical: 10, horizontal: 10));
      } else if (value == 'offlineMode = true' &&
          rabbitData.config.collectionType ==
              DataCollectionType.rotation.name) {
        Get.snackbar('Offline Mode!', 'Let\'s check config',
            colorText: Colors.white,
            backgroundColor: Colors.red.shade300,
            snackPosition: SnackPosition.TOP,
            margin: EdgeInsets.symmetric(vertical: 10, horizontal: 10));
      } else if (value.contains('uploadEvent fail')) {
        Get.snackbar('UploadEvent!', value,
            colorText: Colors.white,
            backgroundColor: Colors.red.shade300,
            snackPosition: SnackPosition.TOP,
            margin: EdgeInsets.symmetric(vertical: 10, horizontal: 10));
      }
    });
  }

  @override
  void dispose() async {
    await dbSub.cancel();
    await conditionSub.cancel();
    await apiSub.cancel();
    super.dispose();
  }

  var events = <RabbitRequest>[].obs;

  Future<void> getEvents() async {
    events.value = await rabbitData.getEvents();
  }

  addEvent(
      {required String eventName,
      required String eventValue,
      Map<String, String>? dataLayer,
      bool isSend = true}) async {
    await rabbitData.addEvent(
        eventName: eventName, eventValue: eventValue, dataLayer: dataLayer);
  }

  uploadEvent() async => await rabbitData.uploadEvent();

  sessionStart() async => await rabbitData.sessionStart();

  sessionEnd() async => await rabbitData.sessionEnd();

  clearCache() async => await rabbitData.clearCache();

  clearAll() async => await rabbitData.clearAll();
}
