import 'package:device_info_plus/device_info_plus.dart';
import 'package:permission_handler/permission_handler.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';
import 'package:shared_preferences/shared_preferences.dart';

class StorageHelper {
  static Future<RabbitDataConfig> initStorageConfig(
      RabbitDataConfig rabbitConfig) async {
    SharedPreferences sharedPreference = await SharedPreferences.getInstance();

    if (sharedPreference.containsKey('collectionType')) {
      var collectionType = sharedPreference.getString('collectionType')!;
      rabbitConfig.collectionType = collectionType == 'Event'
          ? DataCollectionType.event
          : DataCollectionType.rotation;
    }

    if (sharedPreference.containsKey('consent')) {
      var consent = sharedPreference.getString('consent')!;

      rabbitConfig.consent = consent == 'n/a**'
          ? null
          : consent == 'True'
              ? true
              : false;
    }

    if (sharedPreference.containsKey('permissionMaid')) {
      var maid = sharedPreference.getBool('permissionMaid')!;

      var deviceInfoPlugin = DeviceInfoPlugin();
      var deviceInfo = await deviceInfoPlugin.deviceInfo;

      if (deviceInfo is IosDeviceInfo) {
        var version = deviceInfo.systemVersion!;
        var versionNum = int.parse(version.split('.').first);

        if (versionNum <= 13) {
          rabbitConfig.permissionMaid = maid;
        } else {
          rabbitConfig.permissionMaid =
              await Permission.appTrackingTransparency.isGranted ? true : false;
        }
      } else {
        rabbitConfig.permissionMaid = maid;
      }
    }

    if (sharedPreference.containsKey('deleteAfterSent')) {
      var deleteAfterSent = sharedPreference.getBool('deleteAfterSent')!;

      rabbitConfig.deleteAfterSent = deleteAfterSent;
    }

    if (sharedPreference.containsKey('offlineMode')) {
      var offlineMode = sharedPreference.getBool('offlineMode')!;

      rabbitConfig.offlineMode = offlineMode;
    }

    if (sharedPreference.containsKey('retryTime')) {
      var retryTime = sharedPreference.getInt('retryTime')!;

      rabbitConfig.retryTime = retryTime;
    }

    if (sharedPreference.containsKey('retentionDays')) {
      var retentionDays = sharedPreference.getInt('retentionDays')!;

      rabbitConfig.retentionDays = retentionDays;
    }

    if (sharedPreference.containsKey('rotationTime')) {
      var rotationTime = sharedPreference.getInt('rotationTime')!;

      rabbitConfig.rotationTime = rotationTime;
    }

    if (sharedPreference.containsKey('sessionExpire')) {
      var sessionExpire = sharedPreference.getInt('sessionExpire')!;

      rabbitConfig.sessionExpire = sessionExpire;
    }

    if (sharedPreference.containsKey('sessionAutoExpire')) {
      var sessionAutoExpire = sharedPreference.getInt('sessionAutoExpire')!;

      rabbitConfig.sessionAutoExpire = sessionAutoExpire;
    }

    if (sharedPreference.containsKey('cpu') &&
        sharedPreference.containsKey('memory') &&
        sharedPreference.containsKey('betteryLevel')) {
      var cpu = sharedPreference.getInt('cpu') ?? 90;
      var memory = sharedPreference.getInt('memory') ?? 60;
      var batteryLevel = sharedPreference.getInt('betteryLevel') ?? 60;

      rabbitConfig.cpu = cpu;
      rabbitConfig.memory = memory;
      rabbitConfig.batteryLevel = batteryLevel;
    }

    if (sharedPreference.containsKey('storageMin') &&
        sharedPreference.containsKey('storageMax')) {
      var storageMin = sharedPreference.getInt('storageMin') ?? 1;
      var storageMax = sharedPreference.getInt('storageMax') ?? 5;

      rabbitConfig.storageMin = storageMin;
      rabbitConfig.storageMax = storageMax;
    }

    return rabbitConfig;
  }

  static initStorageData(RabbitDataInstance rabbitData) async {
    SharedPreferences sharedPreference = await SharedPreferences.getInstance();

    if (sharedPreference.containsKey('collectionType')) {
      var collectionType = sharedPreference.getString('collectionType')!;
      rabbitData.setDataCollectionType(collectionType == 'Event'
          ? DataCollectionType.event
          : DataCollectionType.rotation);
    }

    if (sharedPreference.containsKey('consent')) {
      var consent = sharedPreference.getString('consent')!;

      rabbitData.setConsent(consent == 'n/a**'
          ? null
          : consent == 'True'
              ? true
              : false);
    }

    if (sharedPreference.containsKey('permissionMaid')) {
      var maid = sharedPreference.getBool('permissionMaid')!;

      rabbitData.setPermissionMaid(maid);
    }

    if (sharedPreference.containsKey('deleteAfterSent')) {
      var deleteAfterSent = sharedPreference.getBool('deleteAfterSent')!;

      rabbitData.setDeleteAfterSent(deleteAfterSent);
    }

    if (sharedPreference.containsKey('offlineMode')) {
      var offlineMode = sharedPreference.getBool('offlineMode')!;

      rabbitData.setOfflineMode(offlineMode);
    }

    if (sharedPreference.containsKey('retryTime')) {
      var retryTime = sharedPreference.getInt('retryTime')!;

      rabbitData.setRetryOnFailed(retryTime);
    }

    if (sharedPreference.containsKey('retentionDays')) {
      var retentionDays = sharedPreference.getInt('retentionDays')!;

      rabbitData.setRetentionDays(retentionDays);
    }

    if (sharedPreference.containsKey('rotationTime')) {
      var rotationTime = sharedPreference.getInt('rotationTime')!;

      rabbitData.setRotationTime(rotationTime);
    }

    if (sharedPreference.containsKey('sessionExpire')) {
      var sessionExpire = sharedPreference.getInt('sessionExpire')!;

      rabbitData.setSessionExpire(sessionExpire);
    }

    if (sharedPreference.containsKey('sessionAutoExpire')) {
      var sessionAutoExpire = sharedPreference.getInt('sessionAutoExpire')!;

      rabbitData.setSessionAutoExpire(sessionAutoExpire);
    }

    if (sharedPreference.containsKey('cpu') &&
        sharedPreference.containsKey('memory') &&
        sharedPreference.containsKey('betteryLevel')) {
      var cpu = sharedPreference.getInt('cpu') ?? 90;
      var memory = sharedPreference.getInt('memory') ?? 60;
      var betteryLevel = sharedPreference.getInt('betteryLevel') ?? 60;

      rabbitData.setTriggerCondition(
          cpu: cpu, memory: memory, batteryLevel: betteryLevel);
    }

    if (sharedPreference.containsKey('storageMin') &&
        sharedPreference.containsKey('storageMax')) {
      var storageMin = sharedPreference.getInt('storageMin') ?? 1;
      var storageMax = sharedPreference.getInt('storageMax') ?? 5;

      rabbitData.setStorageCondition(min: storageMin, max: storageMax);
    }
  }

  static saveStroageData(
      String collectionType,
      String consent,
      bool maid,
      bool deleteAfterSent,
      bool offlineMode,
      int retryTime,
      int retentionDays,
      int rotationTime,
      int sessionExpire,
      int sessionAutoExpire,
      int cpu,
      int memory,
      int betteryLevel,
      int min,
      int max) async {
    SharedPreferences sharedPreference = await SharedPreferences.getInstance();

    await sharedPreference.setString('collectionType', collectionType);

    await sharedPreference.setString('consent', consent);
    await sharedPreference.setBool('permissionMaid', maid);
    await sharedPreference.setBool('deleteAfterSent', deleteAfterSent);
    await sharedPreference.setBool('offlineMode', offlineMode);

    await sharedPreference.setInt('retryTime', retryTime);
    await sharedPreference.setInt('retentionDays', retentionDays);
    await sharedPreference.setInt('rotationTime', rotationTime);
    await sharedPreference.setInt('sessionExpire', sessionExpire);
    await sharedPreference.setInt('sessionAutoExpire', sessionAutoExpire);

    await sharedPreference.setInt('cpu', cpu);
    await sharedPreference.setInt('memory', memory);
    await sharedPreference.setInt('betteryLevel', betteryLevel);

    await sharedPreference.setInt('storageMin', min);
    await sharedPreference.setInt('storageMax', max);
  }
}
