import 'package:flutter/services.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';
import 'package:rdc_flutter_sdk/src/controllers/event_controller.dart';
import 'package:rdc_flutter_sdk/src/controllers/rabbit_config_controller.dart';
import 'package:shared_preferences/shared_preferences.dart';

class LifeCycleController {
  LifeCycleController(
      EventController eventController, RabbitConfigController config) {
    SystemChannels.lifecycle.setMessageHandler((msg) async {
      //print('SystemChannels> $msg');
      switch (msg) {
        case 'AppLifecycleState.inactive':
          eventController.sessionTask?.pause();

          SharedPreferences sharedPreference =
              await SharedPreferences.getInstance();
          if (!sharedPreference.containsKey('pauseTime')) {
            await eventController.onPause();
          }

          break;
        case 'AppLifecycleState.paused':
          if (eventController.session == RabbitSession.start) {
            await eventController.onPause();
          }
          if (config.collectionType == DataCollectionType.rotation.name) {
            eventController.rotationTask?.pause();
          }
          break;
        case 'AppLifecycleState.resumed':
          if (eventController.session == RabbitSession.start) {
            await eventController.onResume();
          }
          if (config.collectionType == DataCollectionType.rotation.name) {
            eventController.rotationTask?.start();
          }
          break;
      }

      return Future.value(null);
    });
  }
}
