import 'dart:async';
import 'package:flutter/services.dart';

class MemoryReader {
  static const MethodChannel _channel = MethodChannel('rdc_flutter_sdk');
  static Future<Memory> get memoryUsed async {
    try {
      var memoryMap = await _channel.invokeMethod('getUsedMemorySize');
      var total = memoryMap['total'];
      var free = memoryMap['free'];
      var load = ((total - free) * 100) / total;
      return Memory(
          usedByApp: memoryMap['usedByApp'],
          loadMem: load,
          total: total,
          free: free,
          lowMemory: memoryMap['lowMemory']);
    } on PlatformException catch (e) {
      throw 'Failed to retrieve memory info ${e.code}: ${e.message}';
    }
  }

  static Future<num> get totalUsagePercent async {
    try {
      var percent = await _channel.invokeMethod('getTotalUsagePercent');
      return percent;
    } on PlatformException catch (e) {
      throw 'Failed to retrieve memory info ${e.code}: ${e.message}';
    }
  }
}

class Memory {
  final num? usedByApp;
  final num? loadMem;
  final num? total;
  final num? free;

  ///
  /// ONLY ANDROID
  /// Not work on iOS
  ///
  final bool? lowMemory;

  Memory({this.usedByApp, this.loadMem, this.total, this.free, this.lowMemory});

  factory Memory.fromMap(Map<String, dynamic> json) => Memory(
      usedByApp: json['usedByApp'],
      loadMem: ((json['total'] - json['free']) * 100) / json['total'],
      total: json['total'],
      free: json['free'],
      lowMemory: json['lowMemory']);

  Map<String, dynamic> toMap() => {
        'usedByApp': loadMem,
        'loadMem': loadMem,
        'total': total,
        'free': free,
        'lowMemory': lowMemory,
      };
}
